@@ -1,3 +1,4 @@
+from re import L
 from arc.middleware import Middleware
 from arc.defaults import LoggingMiddleware, DefaultExceptionHandler
 from arc.staticfiles import StaticFile
@@ -104,13 +105,18 @@ class App:
 
         await self.middleware(scope, receive, send)
 
-    async def handle_request(self, request):
+    async def handle_request(self, request, websocket):
         try:
-            handler, kwargs, methods = self.find_handler(
+            handler, kwargs, methods, type = self.find_handler(
                 request_path=request.url.path)
 
-            assert request.method.lower() in [method.lower(
-            ) for method in methods], f"Method {request.method.lower()} not allowed"
+            if handler is None:
+                pass
+            if type == "websocket":
+                pass
+            else:
+                assert request.method.lower() in [method.lower(
+                ) for method in methods], f"Method {request.method.lower()} not allowed"
 
             try:
                 if handler is not None:
@@ -119,7 +125,10 @@ class App:
                         response = await handler(request, **kwargs)
 
                     else:
-                        response = handler(request, **kwargs)
+                        if type == "route":
+                            response = handler(request, **kwargs)
+                        else:
+                            response = handler(websocket, **args)
                 else:
                     return self.default_response(request)
 
@@ -140,12 +149,16 @@ class App:
     def find_handler(self, request_path):
         for path, items in self.routes.items():
             handler = items["handler"]
-            methods = items["methods"]
+            try:
+                methods = items["methods"]
+            except:
+                methods = None
+            type = items["type"]
             parse_result = parse(path, request_path)
             if parse_result is not None:
-                return handler, parse_result.named, methods
+                return handler, parse_result.named, methods, type
 
-        return None, None, methods
+        return None, None, methods, None
 
     def route(self, path: str, methods=["GET", "POST", "HEAD", "PUT", "DELETE", "CONNECT", "OPTIONS", "TRACE", "PATCH"]):
 
@@ -164,15 +177,23 @@ class App:
     def add_route(self, path, handler, methods=["GET", "POST", "HEAD", "PUT", "DELETE", "CONNECT", "OPTIONS", "TRACE", "PATCH"]):
         assert path not in self.routes, f"Route {path} already exists"
 
-        self.routes[path] = {"handler": handler, "methods": methods}
+        self.routes[path] = {"handler": handler,
+                             "methods": methods, "type": "route"}
 
-    def init_app(self):
+    def websocket(self, path: str):
+        assert path not in self.routes, f"Route {path} already exists"
 
         def wrapper(handler):
-            self.init_app_functions.append(handler)
+            self.add_websocket(path, handler)
+            return handler
 
         return wrapper
 
+    def add_websocket(self, path, handler):
+        assert path not in self.routes, f"Route {path} already exists"
+
+        self.routes[path] = {"handler": handler, "type": "websocket"}
+
     def add_middleware(self, middleware_cls, *args):
         self.middleware.add(middleware_cls, *args)
 
@@ -196,9 +217,6 @@ class App:
         self.collections.append(collection)
 
     def run(self, host: str = None, port: int = None, uvicorn_log_level="critical", reload=False, workers=1, access_log=True) -> None:
-        if "/" not in self.routes:
-            self.add_route("/", self.default_response)
-            
         if host is not None:
             self.host = host
         if port is not None:
